@@ -42,11 +42,10 @@ DiceSetEdit::DiceSetEdit(DiceSet& diceSet)
    removeAction(new Lum::Model::Action()),
    okAction(new Lum::Model::Action())
 {
-  editAction->Disable();
-  cloneAction->Disable();
-  removeAction->Disable();
+  EvaluateRights();
 
   Observe(selection);
+  Observe(name);
 
   Observe(addAction);
   Observe(editAction);
@@ -57,22 +56,41 @@ DiceSetEdit::DiceSetEdit(DiceSet& diceSet)
   Observe(GetClosedAction());
 }
 
-void DiceSetEdit::PreInit()
+void DiceSetEdit::EvaluateRights()
+{
+  if (dicesModel->GetRows()>0 && name->Length()>0) {
+    okAction->Enable();
+  }
+  else {
+    okAction->Disable();
+  }
+
+  if (selection.Valid() && selection->HasSelection()) {
+    editAction->Enable();
+    cloneAction->Enable();
+    removeAction->Enable();
+  }
+  else {
+    editAction->Disable();
+    cloneAction->Disable();
+    removeAction->Disable();
+  }
+}
+
+Lum::Object* DiceSetEdit::GetContent()
 {
   Lum::Label            *label;
-  Lum::Panel            *panel,*horiz;
+  Lum::Panel            *horiz;
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
-  panel=Lum::VPanel::Create();
-
   label=Lum::Label::Create(true,true);
   label->AddLabel(L"Name:",Lum::String::Create(name,true,false));
 
   horiz=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(L"Values",Lum::Base::Size::stdCharWidth,25,true);
+  headerModel->AddColumn(L"Values",Lum::Base::Size::stdCharWidth,20,true);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
@@ -98,13 +116,12 @@ void DiceSetEdit::PreInit()
 
   label->AddLabel(L"Dices:",horiz);
 
-  panel->Add(label);
-  panel->AddSpace();
-  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
+  return label;
+}
 
-  SetMain(panel);
-
-  Dialog::PreInit();
+void DiceSetEdit::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
 }
 
 void DiceSetEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -120,17 +137,8 @@ void DiceSetEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
     result=false;
     Exit();
   }
-  else if (model==selection && dynamic_cast<const Lum::Model::Selection::Selected*>(&msg)!=NULL) {
-    if (selection->HasSelection()) {
-      editAction->Enable();
-      cloneAction->Enable();
-      removeAction->Enable();
-    }
-    else {
-      editAction->Disable();
-      cloneAction->Disable();
-      removeAction->Disable();
-    }
+  else if (model==selection || model==name) {
+    EvaluateRights();
   }
   else if (model==addAction && addAction->IsFinished()) {
     DiceEdit *dialog;
@@ -143,15 +151,16 @@ void DiceSetEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
       dialog->EventLoop();
       dialog->Close();
 
-      // Redraw entry because it name could have changed...
-      dicesModel->Append(dice);
+      if (dialog->GetSuccess()) {
+        dicesModel->Append(dice);
+        EvaluateRights();
+        configurationChanged=true;
+      }
     }
 
     delete dialog;
-
-    configurationChanged=true;
   }
-  else if (model==editAction && editAction->IsFinished()) {
+  else if (model==editAction && editAction->IsFinished() && editAction->IsEnabled()) {
     assert(selection->HasSelection());
 
     DiceEdit *dialog;
@@ -162,34 +171,39 @@ void DiceSetEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
       dialog->EventLoop();
       dialog->Close();
 
-      // Redraw entry because it name could have changed...
-      dicesModel->RedrawRow(selection->GetLine());
+      if (dialog->GetSuccess()) {
+        // Redraw entry because it name could have changed...
+        dicesModel->RedrawRow(selection->GetLine());
+        EvaluateRights();
+        configurationChanged=true;
+      }
     }
 
     delete dialog;
 
-    configurationChanged=true;
   }
-  else if (model==cloneAction && cloneAction->IsFinished()) {
+  else if (model==cloneAction && cloneAction->IsFinished() && cloneAction->IsEnabled()) {
     assert(selection->HasSelection());
 
     Dice dice=dicesModel->GetEntry(selection->GetLine());
 
     dicesModel->Append(dice);
 
+    EvaluateRights();
     configurationChanged=true;
   }
-  else if (model==removeAction && removeAction->IsFinished()) {
+  else if (model==removeAction && removeAction->IsFinished() && removeAction->IsEnabled()) {
     assert(selection->HasSelection());
 
     dicesModel->Delete(selection->GetLine());
     // Could be the currently displayed one
     setsModel->Notify();
 
+    EvaluateRights();
     configurationChanged=true;
   }
 
-  Dialog::Resync(model,msg);
+  Lum::Dlg::ActionDialog::Resync(model,msg);
 }
 
 bool DiceSetEdit::GetResult() const
