@@ -24,7 +24,6 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
-#include <Lum/AppInfo.h>
 #include <Lum/Button.h>
 #include <Lum/Combo.h>
 #include <Lum/Dialog.h>
@@ -46,7 +45,7 @@
 
 #include <iostream>
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class MainDialog : public Lum::Dialog
 {
